@@ -1,8 +1,9 @@
-function run_plaid_link(link_token) {
+function run_plaid_link(link_token, port, received_redirect_uri = null) {
     const handler = Plaid.create({
         token: link_token,
+        receivedRedirectUri: received_redirect_uri,
         onSuccess: (public_token, metadata) => {
-            window.location.replace(`http://localhost:8080/success?public_token=${public_token}`);
+            window.location.replace(`http://localhost:${port}/success?public_token=${public_token}`);
             console.log('public_token', public_token);
             console.log('metadata', metadata);
         },
